This library contains extremely minimal Python bindings of a standard configuration of [opaque-ke](https://github.com/novifinancial/opaque-ke). It exposes 4 functions, which only accept and return base64url-encoded strings.

This library is a counterpart to [@tiptenbrink/opaquewasm](https://github.com/tiptenbrink/opaquewasm).